From ec74645d46b205b83e51c061b2a48af21d898d26 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Fri, 06 Mar 2009 15:52:21 -0500
Subject: [PATCH] - Use US-ASCII as failover when Unicode searching fails (#1485762)   only US-ASCII is a must-have charset from IMAP's RFC

---
 program/include/rcube_imap.php |   11 ++++++-----
 1 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/program/include/rcube_imap.php b/program/include/rcube_imap.php
index 3dbd35d..dbae4e8 100644
--- a/program/include/rcube_imap.php
+++ b/program/include/rcube_imap.php
@@ -955,11 +955,11 @@
 
     $results = $this->_search_index($mailbox, $str, $charset, $sort_field);
 
     // try search with ISO charset (should be supported by server)
     // only if UTF-8 search is not supported
-    if (empty($results) && !is_array($results) && !empty($charset) && $charset!='ISO-8859-1')
+    if (empty($results) && !is_array($results) && !empty($charset) && $charset!='US-ASCII')
       {
 	// convert strings to ISO-8859-1
         if(preg_match_all('/\{([0-9]+)\}\r\n/', $str, $matches, PREG_OFFSET_CAPTURE))
 	  {
 	  $last = 0; $res = '';
@@ -967,7 +967,8 @@
 	    {
 	    $string_offset = $m[1] + strlen($m[0]) + 4; // {}\r\n
 	    $string = substr($str, $string_offset - 1, $m[0]);
-	    $string = rcube_charset_convert($string, $charset, 'ISO-8859-1');
+	    $string = rcube_charset_convert($string, $charset, 'US-ASCII');
+	    if (!$string) continue;
 	    $res .= sprintf("%s{%d}\r\n%s", substr($str, $last, $m[1] - $last - 1), strlen($string), $string);
 	    $last = $m[0] + $string_offset - 1;
 	    }
@@ -977,7 +978,7 @@
 	else // strings for conversion not found
 	  $res = $str;
 	  
-	$results = $this->search($mbox_name, $res, 'ISO-8859-1', $sort_field);
+	$results = $this->search($mbox_name, $res, '', $sort_field);
       }
 
     $this->set_search_set($str, $results, $charset, $sort_field);
@@ -955,11 +955,11 @@
     $results = $this->_search_index($mailbox, $str, $charset, $sort_field);
 
-    // try search with ISO charset (should be supported by server)
+    // try search with US-ASCII charset (should be supported by server)
     // only if UTF-8 search is not supported
@@ -955,11 +955,11 @@
       {
-	// convert strings to ISO-8859-1
+	// convert strings to US_ASCII
         if(preg_match_all('/\{([0-9]+)\}\r\n/', $str, $matches, PREG_OFFSET_CAPTURE))
 	  {

--
Gitblit v1.9.1